"""Coil"""

from __future__ import annotations

from typing import TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.electric_machines import _1253
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_COIL = python_net_import("SMT.MastaAPI.ElectricMachines", "Coil")


__docformat__ = "restructuredtext en"
__all__ = ("Coil",)


Self = TypeVar("Self", bound="Coil")


class Coil(_0.APIBase):
    """Coil

    This is a mastapy class.
    """

    TYPE = _COIL
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_Coil")

    class _Cast_Coil:
        """Special nested class for casting Coil to subclasses."""

        def __init__(self: "Coil._Cast_Coil", parent: "Coil"):
            self._parent = parent

        @property
        def coil(self: "Coil._Cast_Coil") -> "Coil":
            return self._parent

        def __getattr__(self: "Coil._Cast_Coil", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "Coil.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def coil_pitch(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CoilPitch

        if temp is None:
            return 0.0

        return temp

    @property
    def coil_pitch_angle(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CoilPitchAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def in_slot(self: Self) -> "int":
        """int"""
        temp = self.wrapped.InSlot

        if temp is None:
            return 0

        return temp

    @in_slot.setter
    @enforce_parameter_types
    def in_slot(self: Self, value: "int"):
        self.wrapped.InSlot = int(value) if value is not None else 0

    @property
    def in_slot_layer_index(self: Self) -> "int":
        """int"""
        temp = self.wrapped.InSlotLayerIndex

        if temp is None:
            return 0

        return temp

    @in_slot_layer_index.setter
    @enforce_parameter_types
    def in_slot_layer_index(self: Self, value: "int"):
        self.wrapped.InSlotLayerIndex = int(value) if value is not None else 0

    @property
    def in_slot_position(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot":
        """EnumWithSelectedValue[mastapy.electric_machines.CoilPositionInSlot]"""
        temp = self.wrapped.InSlotPosition

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @in_slot_position.setter
    @enforce_parameter_types
    def in_slot_position(self: Self, value: "_1253.CoilPositionInSlot"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.InSlotPosition = value

    @property
    def mean_length_per_turn(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanLengthPerTurn

        if temp is None:
            return 0.0

        return temp

    @property
    def name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def out_slot(self: Self) -> "int":
        """int"""
        temp = self.wrapped.OutSlot

        if temp is None:
            return 0

        return temp

    @out_slot.setter
    @enforce_parameter_types
    def out_slot(self: Self, value: "int"):
        self.wrapped.OutSlot = int(value) if value is not None else 0

    @property
    def out_slot_layer_index(self: Self) -> "int":
        """int"""
        temp = self.wrapped.OutSlotLayerIndex

        if temp is None:
            return 0

        return temp

    @out_slot_layer_index.setter
    @enforce_parameter_types
    def out_slot_layer_index(self: Self, value: "int"):
        self.wrapped.OutSlotLayerIndex = int(value) if value is not None else 0

    @property
    def out_slot_position(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot":
        """EnumWithSelectedValue[mastapy.electric_machines.CoilPositionInSlot]"""
        temp = self.wrapped.OutSlotPosition

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @out_slot_position.setter
    @enforce_parameter_types
    def out_slot_position(self: Self, value: "_1253.CoilPositionInSlot"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_CoilPositionInSlot.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.OutSlotPosition = value

    @property
    def parallel_path(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ParallelPath

        if temp is None:
            return 0

        return temp

    @property
    def phase(self: Self) -> "int":
        """int"""
        temp = self.wrapped.Phase

        if temp is None:
            return 0

        return temp

    @phase.setter
    @enforce_parameter_types
    def phase(self: Self, value: "int"):
        self.wrapped.Phase = int(value) if value is not None else 0

    @property
    def throw(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Throw

        if temp is None:
            return 0

        return temp

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: Self) -> "Coil._Cast_Coil":
        return self._Cast_Coil(self)
