"""CellValuePosition"""

from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_CELL_VALUE_POSITION = python_net_import(
    "SMT.MastaAPI.Utility.ReportingPropertyFramework", "CellValuePosition"
)


__docformat__ = "restructuredtext en"
__all__ = ("CellValuePosition",)


Self = TypeVar("Self", bound="CellValuePosition")


class CellValuePosition(Enum):
    """CellValuePosition

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _CELL_VALUE_POSITION

    LEFT = 0
    CENTER = 1
    RIGHT = 2


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


CellValuePosition.__setattr__ = __enum_setattr
CellValuePosition.__delattr__ = __enum_delattr
